@@ -1,7 +1,7 @@
 from warnings import warn
 from s3fs import S3FileSystem
 from time import sleep
-from botocore.exceptions import NoCredentialsError
+# from botocore.exceptions import NoCredentialsError
 from pandas import read_csv
 from pandas import DataFrame as PandasDF
 from pickle import dump as pickle_dump
@@ -109,10 +109,10 @@ class S3:
 		for try_number in range(1, 5):
 			try:
 				result = self.file_system.exists(path=path)
-				if try_number > 0:
-					print(f'S3 credential issue solved after {try_number} attempt{"s" if try_number > 1 else ""}.')
+				if try_number > 1:
+					print(f'S3 credential issue solved after {try_number} attempts.')
 				return result
-			except NoCredentialsError as exception:
+			except: # NoCredentialsError as exception:
 				print(f'S3 credential issue. Attempt {try_number} failed!')
 				sleep(2 ** (try_number - 1) * 0.2)
 
